Function my_author_fund

pub fn my_author_fund<T: Config>(author: Author<T>, from: FundingTarget<T>)
Inspect the caller’s committed funds towards a specific author.

Resolves the caller’s funding relationship with the given author across the specified funding target.

Behavior

  • Supports Direct, Index, and Pool funding models.
  • Emits the amount currently committed by the caller to the specified author.

Emits: Event::InspectFund

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in [Pallet::my_author_fund].