Function shed_rewards

pub fn shed_rewards<T: Config>()
Shed (expose) all scheduled rewards for the caller i.e., author.

Retrieves and emits the rewards currently scheduled for the caller without modifying state.

Emits: Event::ScheduledRewards via internal hook

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in [Pallet::shed_rewards].