Function transfer_pool

pub fn transfer_pool<T: Config>(pool: PoolDigest<T>, to: T::AccountId)
Transfer management ownership of a funding pool.

Updates the pool manager without affecting custody of funds. The pool remains non-custodial, and all underlying funds, slots, and backing relationships remain unchanged.

Requirements

  • Callable only by the current pool manager.

Behavior

  • Transfers only management control.
  • Does not transfer ownership of any pooled funds.

Emits: Event::PoolManager

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::transfer_pool.